@@ -10,10 +10,8 @@
 #define CATALOGFILEPLUGIN_H
 
 #include <QList>
-#include <QTextCodec>
 class QIODevice;
 class QString;
-class QStringList;
 
 namespace GettextCatalog
 {
@@ -106,7 +104,7 @@ protected:
     void setHeader(const CatalogItem& header);
 
     /** Set the character encoding used in the catalog file. */
-    void setCodec(QTextCodec* codec);
+    void setCodec(const QByteArray &codec);
 
     /** start a new transaction. You should never call this method. */
     void startTransaction();
