@@ -9,7 +9,6 @@
 #ifndef GETTEXTSTORAGE_H
 #define GETTEXTSTORAGE_H
 
-#include <QTextCodec>
 #include <QVector>
 #include "catalogitem.h"
 #include "catalogstorage.h"
@@ -95,18 +94,18 @@ public:
 
 private:
     bool setHeader(const CatalogItem& newHeader);
-    void setCodec(QTextCodec* codec)
+    void setCodec(const QByteArray &codec)
     {
         m_codec = codec;
     }
 
-    QVector<Note> notes(const DocPosition& pos, const QRegExp& re, int preLen) const;
+    QVector<Note> notes(const DocPosition& pos, const QRegularExpression& re, int preLen) const;
 
 private:
     QVector<CatalogItem> m_entries;
     QVector<CatalogItem> m_obsoleteEntries;
     CatalogItem m_header;
-    QTextCodec* m_codec{nullptr};
+    QByteArray m_codec;
 
     short m_maxLineLength{80};
     short m_trailingNewLines{0};
