@@ -11,6 +11,7 @@
 
 #include "lokalize_debug.h"
 
+#include "gettextheaderparser.h"
 #include "project.h"
 
 #include "version.h"
@@ -23,9 +24,9 @@
 #include <QString>
 #include <QStringBuilder>
 #include <QMap>
-#include <QTextCodec>
 #include <QDateTime>
 #include <QTimeZone>
+#include <QRegularExpression>
 
 #include <klocalizedstring.h>
 
@@ -118,11 +119,12 @@ static const size_t langsWithPInfoCount = sizeof(langsWithPInfo) / sizeof(langsW
 
 int numberOfPluralFormsFromHeader(const QString& header)
 {
-    QRegExp rxplural(QStringLiteral("Plural-Forms:\\s*nplurals=(.);"));
-    if (rxplural.indexIn(header) == -1)
+    const QRegularExpression rxplural(QStringLiteral("Plural-Forms:\\s*nplurals=(.);"));
+    const auto match = rxplural.match(header);
+    if (!match.hasMatch())
         return 0;
     bool ok{};
-    int result = rxplural.cap(1).toShort(&ok);
+    int result = match.capturedView(1).toShort(&ok);
     return ok ? result : 0;
 
 }
@@ -131,11 +133,12 @@ int numberOfPluralFormsForLangCode(const QString& langCode)
 {
     QString expr = GNUPluralForms(langCode);
 
-    QRegExp rxplural(QStringLiteral("nplurals=(.);"));
-    if (rxplural.indexIn(expr) == -1)
+    const QRegularExpression rxplural(QStringLiteral("nplurals=(.);"));
+    const auto match = rxplural.match(expr);
+    if (!match.hasMatch())
         return 0;
     bool ok;
-    int result = rxplural.cap(1).toShort(&ok);
+    int result = match.capturedView(1).toShort(&ok);
     return ok ? result : 0;
 
 }
@@ -247,7 +250,7 @@ void updateHeader(QString& header,
                   bool generatedFromDocbook,
                   bool belongsToProject,
                   bool forSaving,
-                  QTextCodec* codec)
+                  const QString& codec)
 {
     askAuthorInfoIfEmpty();
 
@@ -257,8 +260,6 @@ void updateHeader(QString& header,
 //BEGIN header itself
     QStringList::Iterator it, ait;
     QString temp;
-    QString authorNameEmail;
-
     const QString BACKSLASH_N = QStringLiteral("\\n");
 
     // Unwrap header since the following code
@@ -279,24 +280,11 @@ void updateHeader(QString& header,
         }
     }
 
+    GetTextHeaderParser::updateLastTranslator(headerList, Settings::authorName(), Settings::authorEmail());
+
     bool found = false;
-    authorNameEmail = Settings::authorName();
-    if (!Settings::authorEmail().isEmpty())
-        authorNameEmail += (QStringLiteral(" <") + Settings::authorEmail() + QLatin1Char('>'));
-    temp = QStringLiteral("Last-Translator: ") + authorNameEmail + BACKSLASH_N;
-
-    QRegExp lt(QStringLiteral("^ *Last-Translator:.*"));
-    for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
-        if (it->contains(lt)) {
-            if (forSaving) *it = temp;
-            found = true;
-        }
-    }
-    if (Q_UNLIKELY(!found))
-        headerList.append(temp);
-
     temp = QStringLiteral("PO-Revision-Date: ") + formatGettextDate(QDateTime::currentDateTime()) + BACKSLASH_N;
-    QRegExp poRevDate(QStringLiteral("^ *PO-Revision-Date:.*"));
+    const QRegularExpression poRevDate(QStringLiteral("^ *PO-Revision-Date:.*"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
         found = it->contains(poRevDate);
         if (found && forSaving) *it = temp;
@@ -306,7 +294,7 @@ void updateHeader(QString& header,
 
     temp = QStringLiteral("Project-Id-Version: ") + CatalogProjectId + BACKSLASH_N;
     //temp.replace( "@PACKAGE@", packageName());
-    QRegExp projectIdVer(QStringLiteral("^ *Project-Id-Version:.*"));
+    const QRegularExpression projectIdVer(QStringLiteral("^ *Project-Id-Version:.*"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
         found = it->contains(projectIdVer);
         if (found && it->contains(QLatin1String("PACKAGE VERSION")))
@@ -327,16 +315,16 @@ void updateHeader(QString& header,
         for (int l = QLocale::Abkhazian; l <= QLocale::Akoose; ++l)
             langEnums[QLocale::languageToString((QLocale::Language)l)] = (QLocale::Language)l;
 
-    static QRegExp langTeamRegExp(QStringLiteral("^ *Language-Team:.*"));
+    static const QRegularExpression langTeamRegExp(QStringLiteral("^ *Language-Team:.*"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
         found = it->contains(langTeamRegExp);
         if (found) {
             //really parse header
-            QRegExp re(QStringLiteral("^ *Language-Team: *(.*) *<([^>]*)>"));
-            if (re.indexIn(*it) != -1) {
-                if (langEnums.contains(re.cap(1).trimmed())) {
-                    language = re.cap(1).trimmed();
-                    mailingList = re.cap(2).trimmed();
+            const QRegularExpression re(QStringLiteral("^ *Language-Team: *(.*) *<([^>]*)>"));
+            if (const auto match = re.match(*it); match.hasMatch()) {
+                if (langEnums.contains(match.captured(1).trimmed())) {
+                    language = match.captured(1).trimmed();
+                    mailingList = match.captured(2).trimmed();
                     QList<QLocale> locales = QLocale::matchingLocales(langEnums.value(language), QLocale::AnyScript, QLocale::AnyCountry);
                     if (locales.size()) langCode = locales.first().name().left(2);
                 }
@@ -373,19 +361,20 @@ void updateHeader(QString& header,
     else
         headerList.append(temp);
 
-    static QRegExp langCodeRegExp(QStringLiteral("^ *Language: *([^ \\\\]*)"));
+    static const QRegularExpression langCodeRegExp(QStringLiteral("^ *Language: *([^ \\\\]*)"));
     temp = QStringLiteral("Language: ") + langCode + BACKSLASH_N;
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
-        found = (langCodeRegExp.indexIn(*it) != -1);
-        if (found && langCodeRegExp.cap(1).isEmpty())
+        const auto match = langCodeRegExp.match(*it);
+        found = match.hasMatch();
+        if (found && match.captured(1).isEmpty())
             *it = temp;
         //if (found) qCWarning(LOKALIZE_LOG)<<"got explicit lang code:"<<langCodeRegExp.cap(1);
     }
     if (Q_UNLIKELY(!found))
         headerList.append(temp);
 
-    temp = QStringLiteral("Content-Type: text/plain; charset=") + QString::fromLatin1(codec->name()) + BACKSLASH_N;
-    QRegExp ctRe(QStringLiteral("^ *Content-Type:.*"));
+    temp = QStringLiteral("Content-Type: text/plain; charset=") + codec + BACKSLASH_N;
+    const QRegularExpression ctRe(QStringLiteral("^ *Content-Type:.*"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
         found = it->contains(ctRe);
         if (found) *it = temp;
@@ -395,7 +384,7 @@ void updateHeader(QString& header,
 
 
     temp = QStringLiteral("Content-Transfer-Encoding: 8bit\\n");
-    QRegExp cteRe(QStringLiteral("^ *Content-Transfer-Encoding:.*"));
+    const QRegularExpression cteRe(QStringLiteral("^ *Content-Transfer-Encoding:.*"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it)
         found = it->contains(cteRe);
     if (!found)
@@ -403,7 +392,7 @@ void updateHeader(QString& header,
 
     // ensure MIME-Version header
     temp = QStringLiteral("MIME-Version: 1.0\\n");
-    QRegExp mvRe(QStringLiteral("^ *MIME-Version:"));
+    const QRegularExpression mvRe(QStringLiteral("^ *MIME-Version:"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
         found = it->contains(mvRe);
         if (found) *it = temp;
@@ -414,7 +403,7 @@ void updateHeader(QString& header,
 
     //qCDebug(LOKALIZE_LOG)<<"testing for GNUPluralForms";
     // update plural form header
-    QRegExp pfRe(QStringLiteral("^ *Plural-Forms:"));
+    const QRegularExpression pfRe(QStringLiteral("^ *Plural-Forms:"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it)
         found = it->contains(pfRe);
     if (found) {
@@ -430,8 +419,7 @@ void updateHeader(QString& header,
                 QString t = GNUPluralForms(langCode);
                 //qCWarning(LOKALIZE_LOG)<<"generated: " << t;
                 if (!t.isEmpty()) {
-                    static QRegExp pf(QStringLiteral("^ *Plural-Forms:\\s*nplurals.*\\\\n"));
-                    pf.setMinimal(true);
+                    static const QRegularExpression pf(QStringLiteral("^ *Plural-Forms:\\s*nplurals.*\\\\n"), QRegularExpression::InvertedGreedinessOption);
                     temp = QStringLiteral("Plural-Forms: %1\\n").arg(t);
                     it->replace(pf, temp);
                     num = numberOfPluralFormsFromHeader(temp);
@@ -455,7 +443,7 @@ void updateHeader(QString& header,
     }
 
     temp = QStringLiteral("X-Generator: Lokalize %1\\n").arg(QStringLiteral(LOKALIZE_VERSION));
-    QRegExp xgRe(QStringLiteral("^ *X-Generator:.*"));
+    const QRegularExpression xgRe(QStringLiteral("^ *X-Generator:.*"));
     for (it = headerList.begin(), found = false; it != headerList.end() && !found; ++it) {
         found = it->contains(xgRe);
         if (found) *it = temp;
@@ -463,107 +451,14 @@ void updateHeader(QString& header,
     if (Q_UNLIKELY(!found))
         headerList.append(temp);
 
-    //m_header.setMsgstr( headerList.join( "\n" ) );
     header = headerList.join(QStringLiteral("\n"));
 //END header itself
 
 //BEGIN comment = description, copyrights
-    QLocale cLocale(QLocale::C);
-    // U+00A9 is the Copyright sign
-    QRegExp fsfc(QStringLiteral("^# *Copyright (\\(C\\)|\\x00a9).*Free Software Foundation, Inc"));
-    for (it = commentList.begin(), found = false; it != commentList.end() && !found; ++it) {
-        found = it->contains(fsfc) ;
-        if (found) {
-            it->replace(QStringLiteral("YEAR"), cLocale.toString(QDate::currentDate(), QStringLiteral("yyyy")));
-        }
-    }
+    GetTextHeaderParser::updateGeneralCopyrightYear(commentList);
+    // qCDebug(LOKALIZE_LOG) << "HEADER COMMENT: " << commentList;
 
-    QStringList foundAuthors;
-
-    temp = QStringLiteral("# ") + authorNameEmail + QStringLiteral(", ") + cLocale.toString(QDate::currentDate(), QStringLiteral("yyyy")) + QLatin1Char('.');
-
-    // ### TODO: it would be nice if the entry could start with "COPYRIGHT" and have the "(C)" symbol (both not mandatory)
-    QRegExp regexpAuthorYear(QStringLiteral("^#.*(<.+@.+>)?,\\s*([\\d]+[\\d\\-, ]*|YEAR)"));
-    QRegExp regexpYearAlone(QStringLiteral("^# , \\d{4}.?\\s*$"));
-    QRegExp regexpFuzzy(QStringLiteral("#, *fuzzy"));
-    if (commentList.isEmpty()) {
-        commentList.append(temp);
-        commentList.append(QString());
-    } else {
-        it = commentList.begin();
-        while (it != commentList.end()) {
-            bool deleteItem = false;
-            if (it->indexOf(QLatin1String("copyright"), 0, Qt::CaseInsensitive) != -1) {
-                // We have a line with a copyright. It should not be moved.
-            } else if (regexpFuzzy.indexIn(*it) != -1)
-                deleteItem = true;
-            else if (regexpYearAlone.indexIn(*it) != -1) {
-                // We have found a year number that is preceded by a comma.
-                // That is typical of KBabel 1.10 (and earlier?) when there is neither an author name nor an email
-                // Remove the entry
-                deleteItem = true;
-            } else if (it->contains(QLatin1String("# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.")))
-                deleteItem = true;
-            else if (it->contains(QLatin1String("# SOME DESCRIPTIVE TITLE")))
-                deleteItem = true;
-            else if (regexpAuthorYear.indexIn(*it) != -1) {   // email address followed by year
-                if (!foundAuthors.contains((*it))) {
-                    // The author line is new (and not a duplicate), so add it to the author line list
-                    foundAuthors.append((*it));
-                }
-                // Delete also non-duplicated entry, as now all what is needed will be processed in foundAuthors
-                deleteItem = true;
-            }
-
-            if (deleteItem)
-                it = commentList.erase(it);
-            else
-                ++it;
-        }
-
-        if (!foundAuthors.isEmpty()) {
-            found = false;
-            bool foundAuthor = false;
-
-            const QString cy = cLocale.toString(QDate::currentDate(), QStringLiteral("yyyy"));
-
-            ait = foundAuthors.end();
-            for (it = foundAuthors.begin() ; it != foundAuthors.end(); ++it) {
-                if (it->contains(Settings::authorName()) || it->contains(Settings::authorEmail())) {
-                    foundAuthor = true;
-                    if (it->contains(cy))
-                        found = true;
-                    else
-                        ait = it;
-                }
-            }
-            if (!found) {
-                if (!foundAuthor)
-                    foundAuthors.append(temp);
-                else if (ait != foundAuthors.end()) {
-                    //update years
-                    QRegExp regExp(QStringLiteral("[\\d]+[\\d\\-, ]*"));
-                    const int index = regExp.lastIndexIn(*ait);
-                    if (index == -1)
-                        (*ait) += QStringLiteral(", ") + cy;
-                    else
-                        ait->insert(index + 1, QStringLiteral(", ") + cy);
-                } else
-                    qCDebug(LOKALIZE_LOG) << "INTERNAL ERROR: author found but iterator dangling!";
-            }
-
-        } else
-            foundAuthors.append(temp);
-
-
-        for (QString author : qAsConst(foundAuthors)) {
-            // ensure dot at the end of copyright
-            if (!author.endsWith(QLatin1Char('.'))) author += QLatin1Char('.');
-            commentList.append(author);
-        }
-    }
-
-    //m_header.setComment( commentList.join( "\n" ) );
+    GetTextHeaderParser::updateAuthors(commentList, Settings::authorName(), Settings::authorEmail());
     comment = commentList.join(QStringLiteral("\n"));
 
 //END comment = description, copyrights
