@@ -22,17 +22,12 @@
 
 #include "completionstorage.h"
 
-#define WEBQUERY_ENABLE
-
 //views
 #include "msgctxtview.h"
 #include "alttransview.h"
 #include "mergeview.h"
 #include "cataloglistview.h"
 #include "glossaryview.h"
-#ifdef WEBQUERY_ENABLE
-#include "webqueryview.h"
-#endif
 #include "tmview.h"
 #include "binunitsview.h"
 
@@ -207,7 +202,7 @@ void EditorTab::setupActions()
     QAction* altaction;
     for (int i = 0; i < ALTTRANS_SHORTCUTS; ++i) {
         altaction = tm->addAction(QStringLiteral("alttrans_insert_%1").arg(i));
-        ac->setDefaultShortcut(altaction, QKeySequence(Qt::ALT + altlist[i]));
+        ac->setDefaultShortcut(altaction, QKeySequence(Qt::AltModifier | altlist[i]));
         altaction->setText(i18nc("@action:inmenu", "Insert alternate translation #%1", QString::number(i)));
         altactions[i] = altaction;
     }
@@ -251,10 +246,10 @@ void EditorTab::setupActions()
     connect(m_view, &EditorView::signalChanged, m_notesView, &MsgCtxtView::removeErrorNotes);
     connect(m_notesView, &MsgCtxtView::escaped, this, &EditorTab::setProperFocus);
 
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::languageToolChanged, m_notesView, &MsgCtxtView::languageTool);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::languageToolChanged, m_notesView, &MsgCtxtView::languageTool);
 
     action = edit->addAction(QStringLiteral("edit_addnote"), m_notesView, SLOT(addNoteUI()));
-    //action->setShortcut(Qt::CTRL+glist[i]);
+    //action->setShortcut(Qt::ControlModifier+glist[i]);
     action->setText(i18nc("@action:inmenu", "Add a note"));
 
     QVector<QAction*> tmactions_insert(TM_SHORTCUTS);
@@ -275,19 +270,19 @@ void EditorTab::setupActions()
     for (int i = 0; i < TM_SHORTCUTS; ++i) {
 //         action->setVisible(false);
         tmaction = tm->addAction(QStringLiteral("tmquery_insert_%1").arg(i));
-        ac->setDefaultShortcut(tmaction, QKeySequence(Qt::CTRL + tmlist[i]));
+        ac->setDefaultShortcut(tmaction, QKeySequence(Qt::ControlModifier | tmlist[i]));
         tmaction->setText(i18nc("@action:inmenu", "Insert TM suggestion #%1", i + 1));
         tmactions_insert[i] = tmaction;
 
         tmaction = tm->addAction(QStringLiteral("tmquery_remove_%1").arg(i));
-        ac->setDefaultShortcut(tmaction, QKeySequence(Qt::CTRL + Qt::ALT + tmlist[i]));
+        ac->setDefaultShortcut(tmaction, QKeySequence(Qt::ControlModifier | Qt::AltModifier | tmlist[i]));
         tmaction->setText(i18nc("@action:inmenu", "Remove TM suggestion #%1", i + 1));
         tmactions_remove[i] = tmaction;
     }
 #ifndef Q_OS_DARWIN
     if (systemLang == QLocale::Czech) {
-        ac->setDefaultShortcuts(tmactions_insert[0], QList<QKeySequence>() << QKeySequence(Qt::CTRL + tmlist[0]) << QKeySequence(Qt::CTRL + Qt::Key_Plus));
-        ac->setDefaultShortcuts(tmactions_remove[0], QList<QKeySequence>() << QKeySequence(Qt::CTRL + Qt::ALT + tmlist[0]) << QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Plus));
+        ac->setDefaultShortcuts(tmactions_insert[0], QList<QKeySequence>() << QKeySequence(Qt::ControlModifier | tmlist[0]) << QKeySequence(Qt::ControlModifier | Qt::Key_Plus));
+        ac->setDefaultShortcuts(tmactions_remove[0], QList<QKeySequence>() << QKeySequence(Qt::ControlModifier | Qt::AltModifier | tmlist[0]) << QKeySequence(Qt::ControlModifier | Qt::AltModifier | Qt::Key_Plus));
     }
 #endif
     TM::TMView* _tmView = new TM::TMView(this, m_catalog, tmactions_insert, tmactions_remove);
@@ -329,7 +324,7 @@ void EditorTab::setupActions()
     for (int i = 0; i < GLOSSARY_SHORTCUTS; ++i) {
 //         action->setVisible(false);
         gaction = glossary->addAction(QStringLiteral("glossary_insert_%1").arg(i));
-        ac->setDefaultShortcut(gaction, QKeySequence(Qt::CTRL + glist[i]));
+        ac->setDefaultShortcut(gaction, QKeySequence(Qt::ControlModifier | glist[i]));
         gaction->setText(i18nc("@action:inmenu", "Insert term translation #%1", QString::number(i)));
         gactions[i] = gaction;
     }
@@ -352,38 +347,6 @@ void EditorTab::setupActions()
     connect(m_view, &EditorView::binaryUnitSelectRequested, binUnitsView, &BinUnitsView::selectUnit);
 
 
-//#ifdef WEBQUERY_ENABLE
-#if 0
-    QVector<QAction*> wqactions(WEBQUERY_SHORTCUTS);
-    Qt::Key wqlist[WEBQUERY_SHORTCUTS] = {
-        Qt::Key_1,
-        Qt::Key_2,
-        Qt::Key_3,
-        Qt::Key_4,
-        Qt::Key_5,
-        Qt::Key_6,
-        Qt::Key_7,
-        Qt::Key_8,
-        Qt::Key_9,
-        Qt::Key_0,
-    };
-    QAction* wqaction;
-    for (i = 0; i < WEBQUERY_SHORTCUTS; ++i) {
-//         action->setVisible(false);
-        wqaction = ac->addAction(QString("webquery_insert_%1").arg(i));
-        wqaction->setShortcut(Qt::CTRL + Qt::ALT + wqlist[i]);
-        //wqaction->setShortcut(Qt::META+wqlist[i]);
-        wqaction->setText(i18nc("@action:inmenu", "Insert WebQuery result #%1", i));
-        wqactions[i] = wqaction;
-    }
-    WebQueryView* _webQueryView = new WebQueryView(this, m_catalog, wqactions);
-    addDockWidget(Qt::BottomDockWidgetArea, _webQueryView);
-    ac->addAction(QStringLiteral("showwebqueryview_action"), _webQueryView->toggleViewAction());
-    connect(this, &EditorTab::signalNewEntryDisplayed, _webQueryView, SLOT(slotNewEntryDisplayed(DocPosition)));
-    connect(_webQueryView, SIGNAL(textInsertRequested(QString)), m_view, SLOT(insertTerm(QString)));
-#endif
-
-
 //END dockwidgets
 
 
@@ -417,17 +380,17 @@ void EditorTab::setupActions()
     action->setText(i18nc("@action:inmenu", "Phases..."));
     connect(action, &QAction::triggered, this, &EditorTab::openPhasesWindow);
 
-    ADD_ACTION_SHORTCUT("file_wordcount", i18nc("@action:inmenu", "Word count"), Qt::CTRL + Qt::ALT + Qt::Key_C)
+    ADD_ACTION_SHORTCUT("file_wordcount", i18nc("@action:inmenu", "Word count"), Qt::ControlModifier | Qt::AltModifier | Qt::Key_C)
     connect(action, &QAction::triggered, this, &EditorTab::displayWordCount);
 
-    ADD_ACTION_SHORTCUT("file_cleartarget", i18nc("@action:inmenu", "Clear all translated entries"), Qt::CTRL + Qt::ALT + Qt::Key_D)
+    ADD_ACTION_SHORTCUT("file_cleartarget", i18nc("@action:inmenu", "Clear all translated entries"), Qt::ControlModifier | Qt::AltModifier | Qt::Key_D)
     connect(action, &QAction::triggered, this, &EditorTab::clearTranslatedEntries);
 
-    ADD_ACTION_SHORTCUT("file_pology", i18nc("@action:inmenu", "Launch the Pology command on this file"), Qt::CTRL + Qt::ALT + Qt::Key_P)
+    ADD_ACTION_SHORTCUT("file_pology", i18nc("@action:inmenu", "Launch the Pology command on this file"), Qt::ControlModifier | Qt::AltModifier | Qt::Key_P)
     action->setEnabled(Settings::self()->pologyEnabled());
     connect(action, &QAction::triggered, this, &EditorTab::launchPology);
 
-    ADD_ACTION_SHORTCUT("file_xliff2odf", i18nc("@action:inmenu", "Merge translation into OpenDocument"), Qt::CTRL + Qt::Key_Backslash)
+    ADD_ACTION_SHORTCUT("file_xliff2odf", i18nc("@action:inmenu", "Merge translation into OpenDocument"), Qt::ControlModifier | Qt::Key_Backslash)
     connect(action, &QAction::triggered, this, &EditorTab::mergeIntoOpenDocument);
     connect(this, &EditorTab::xliffFileOpened, action, &QAction::setVisible);
     action->setVisible(false);
@@ -436,12 +399,12 @@ void EditorTab::setupActions()
 //Edit
     actionCategory = edit;
     action = edit->addAction(KStandardAction::Undo, this, SLOT(undo()));
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::undoRequested, this, &EditorTab::undo);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::undoRequested, this, &EditorTab::undo);
     connect(m_catalog, &Catalog::canUndoChanged, action, &QAction::setEnabled);
     action->setEnabled(false);
 
     action = edit->addAction(KStandardAction::Redo, this, SLOT(redo()));
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::redoRequested, this, &EditorTab::redo);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::redoRequested, this, &EditorTab::redo);
     connect(m_catalog, &Catalog::canRedoChanged, action, &QAction::setEnabled);
     action->setEnabled(false);
 
@@ -457,10 +420,12 @@ void EditorTab::setupActions()
 
 
 
-    action = actionCategory->addAction(QStringLiteral("edit_approve"),
-                                       new KToolBarPopupAction(QIcon::fromTheme(QStringLiteral("approved")),
-                                               i18nc("@option:check whether message is marked as translated/reviewed/approved (depending on your role)", "Approved"), this));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_U));
+    m_approveAction = new KToolBarPopupAction(QIcon::fromTheme(QStringLiteral("approved")),
+                                               i18nc("@option:check whether message is marked as translated/reviewed/approved (depending on your role)", "Approved"), this);
+    m_stateAction = m_approveAction;
+
+    action = actionCategory->addAction(QStringLiteral("edit_approve"), m_approveAction);
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_U));
 
     action->setCheckable(true);
     connect(action, &QAction::triggered, m_view, &EditorView::toggleApprovement);
@@ -468,12 +433,10 @@ void EditorTab::setupActions()
     connect(this, &EditorTab::signalApprovedEntryDisplayed, action, &QAction::setChecked);
     connect(this, &EditorTab::signalApprovedEntryDisplayed, this, &EditorTab::msgStrChanged, Qt::QueuedConnection);
 
-    m_approveAction = action;
-    m_stateAction = action;
     connect(Project::local(), &ProjectLocal::configChanged, this, &EditorTab::setApproveActionTitle);
     connect(m_catalog, &Catalog::activePhaseChanged, this, &EditorTab::setApproveActionTitle);
-    connect(m_stateAction->menu(), &QMenu::aboutToShow, this, &EditorTab::showStatesMenu);
-    connect(m_stateAction->menu(), &QMenu::triggered, this, &EditorTab::setState);
+    connect(m_stateAction->popupMenu(), &QMenu::aboutToShow, this, &EditorTab::showStatesMenu);
+    connect(m_stateAction->popupMenu(), &QMenu::triggered, this, &EditorTab::setState);
 
 
     action = actionCategory->addAction(QStringLiteral("edit_approve_go_fuzzyUntr"));
@@ -492,43 +455,43 @@ void EditorTab::setupActions()
 
 
 #ifndef Q_OS_DARWIN
-    int copyShortcut = Qt::CTRL + Qt::Key_Space;
+    QKeyCombination copyShortcut = Qt::ControlModifier | Qt::Key_Space;
     if (Q_UNLIKELY(systemLang == QLocale::Korean
                    || systemLang == QLocale::Japanese
                    || systemLang == QLocale::Chinese
                   ))
-        copyShortcut = Qt::ALT + Qt::Key_Space;
+        copyShortcut = Qt::AltModifier | Qt::Key_Space;
 #else
-    int copyShortcut = Qt::META + Qt::Key_Space;
+    QKeyCombination copyShortcut = Qt::META | Qt::Key_Space;
 #endif
     ADD_ACTION_SHORTCUT_ICON("edit_msgid2msgstr", i18nc("@action:inmenu", "Copy source to target"), copyShortcut, "msgid2msgstr")
-    connect(action, &QAction::triggered, (const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::source2target);
+    connect(action, &QAction::triggered, m_view->viewPort(), &TranslationUnitTextEdit::source2target);
 
-    ADD_ACTION_SHORTCUT("edit_unwrap-target", i18nc("@action:inmenu", "Unwrap target"), Qt::CTRL + Qt::Key_I)
+    ADD_ACTION_SHORTCUT("edit_unwrap-target", i18nc("@action:inmenu", "Unwrap target"), Qt::ControlModifier | Qt::Key_I)
     connect(action, &QAction::triggered, m_view, qOverload<>(&EditorView::unwrap));
 
     action = edit->addAction(QStringLiteral("edit_clear-target"), m_view->viewPort(), SLOT(removeTargetSubstring()));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_D));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_D));
     action->setText(i18nc("@action:inmenu", "Clear"));
 
     action = edit->addAction(QStringLiteral("edit_tagmenu"), m_view->viewPort(), SLOT(tagMenu()));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_T));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_T));
     action->setText(i18nc("@action:inmenu", "Insert Tag"));
 
     action = edit->addAction(QStringLiteral("edit_languagetool"), m_view->viewPort(), SLOT(launchLanguageTool()));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_J));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_J));
     action->setText(i18nc("@action:inmenu", "Check this unit using LanguageTool"));
 
     action = edit->addAction(QStringLiteral("edit_tagimmediate"), m_view->viewPort(), SLOT(tagImmediate()));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_M));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_M));
     action->setText(i18nc("@action:inmenu", "Insert Next Tag"));
 
     action = edit->addAction(QStringLiteral("edit_completion"), m_view, SIGNAL(doExplicitCompletion()));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Space));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::AltModifier | Qt::Key_Space));
     action->setText(i18nc("@action:inmenu", "Completion"));
 
     action = edit->addAction(QStringLiteral("edit_spellreplace"), m_view->viewPort(), SLOT(spellReplace()));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_Equal));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_Equal));
     action->setText(i18nc("@action:inmenu", "Replace with best spellcheck suggestion"));
 //     action = ac->addAction("glossary_define",m_view,SLOT(defineNewTerm()));
 //     action->setText(i18nc("@action:inmenu","Define new term"));
@@ -538,61 +501,61 @@ void EditorTab::setupActions()
     action = nav->addAction(KStandardAction::Next, this, SLOT(gotoNext()));
     action->setText(i18nc("@action:inmenu entry", "&Next"));
     connect(this, &EditorTab::signalLastDisplayed, action, &QAction::setDisabled);
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoNextRequested, this, &EditorTab::gotoNext);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoNextRequested, this, &EditorTab::gotoNext);
 
     action = nav->addAction(KStandardAction::Prior, this, SLOT(gotoPrev()));
     action->setText(i18nc("@action:inmenu entry", "&Previous"));
     connect(this, &EditorTab::signalFirstDisplayed, action, &QAction::setDisabled);
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevRequested, this, &EditorTab::gotoPrev);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevRequested, this, &EditorTab::gotoPrev);
 
     action = nav->addAction(KStandardAction::FirstPage, this, SLOT(gotoFirst()));
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoFirstRequested, this, &EditorTab::gotoFirst);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoFirstRequested, this, &EditorTab::gotoFirst);
     action->setText(i18nc("@action:inmenu", "&First Entry"));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Home));
+    action->setShortcut(QKeySequence(Qt::ControlModifier | Qt::AltModifier | Qt::Key_Home));
     connect(this, &EditorTab::signalFirstDisplayed, action, &QAction::setDisabled);
 
     action = nav->addAction(KStandardAction::LastPage, this, SLOT(gotoLast()));
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoLastRequested, this, &EditorTab::gotoLast);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoLastRequested, this, &EditorTab::gotoLast);
     action->setText(i18nc("@action:inmenu", "&Last Entry"));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_End));
+    action->setShortcut(QKeySequence(Qt::ControlModifier | Qt::AltModifier | Qt::Key_End));
     connect(this, &EditorTab::signalLastDisplayed, action, &QAction::setDisabled);
 
     action = nav->addAction(KStandardAction::GotoPage, this, SLOT(gotoEntry()));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_G));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_G));
     action->setText(i18nc("@action:inmenu", "Entry by number"));
 
-    ADD_ACTION_SHORTCUT_ICON("go_prev_fuzzy", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Previous non-empty but not ready"), Qt::CTRL + Qt::Key_PageUp, "prevfuzzy")
+    ADD_ACTION_SHORTCUT_ICON("go_prev_fuzzy", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Previous non-empty but not ready"), Qt::ControlModifier | Qt::Key_PageUp, "prevfuzzy")
     connect(action, &QAction::triggered, this, &EditorTab::gotoPrevFuzzy);
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevFuzzyRequested, this, &EditorTab::gotoPrevFuzzy);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevFuzzyRequested, this, &EditorTab::gotoPrevFuzzy);
     connect(this, &EditorTab::signalPriorFuzzyAvailable, action, &QAction::setEnabled);
 
-    ADD_ACTION_SHORTCUT_ICON("go_next_fuzzy", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Next non-empty but not ready"), Qt::CTRL + Qt::Key_PageDown, "nextfuzzy")
+    ADD_ACTION_SHORTCUT_ICON("go_next_fuzzy", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Next non-empty but not ready"), Qt::ControlModifier | Qt::Key_PageDown, "nextfuzzy")
     connect(action, &QAction::triggered, this, &EditorTab::gotoNextFuzzy);
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoNextFuzzyRequested, this, &EditorTab::gotoNextFuzzy);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoNextFuzzyRequested, this, &EditorTab::gotoNextFuzzy);
     connect(this, &EditorTab::signalNextFuzzyAvailable, action, &QAction::setEnabled);
 
-    ADD_ACTION_SHORTCUT_ICON("go_prev_untrans", i18nc("@action:inmenu", "Previous untranslated"), Qt::ALT + Qt::Key_PageUp, "prevuntranslated")
+    ADD_ACTION_SHORTCUT_ICON("go_prev_untrans", i18nc("@action:inmenu", "Previous untranslated"), Qt::AltModifier | Qt::Key_PageUp, "prevuntranslated")
     connect(action, &QAction::triggered, this, &EditorTab::gotoPrevUntranslated);
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevUntranslatedRequested, this, &EditorTab::gotoPrevUntranslated);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevUntranslatedRequested, this, &EditorTab::gotoPrevUntranslated);
     connect(this, &EditorTab::signalPriorUntranslatedAvailable, action, &QAction::setEnabled);
 
-    ADD_ACTION_SHORTCUT_ICON("go_next_untrans", i18nc("@action:inmenu", "Next untranslated"), Qt::ALT + Qt::Key_PageDown, "nextuntranslated")
+    ADD_ACTION_SHORTCUT_ICON("go_next_untrans", i18nc("@action:inmenu", "Next untranslated"), Qt::AltModifier | Qt::Key_PageDown, "nextuntranslated")
     connect(action, &QAction::triggered, this, &EditorTab::gotoNextUntranslated);
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoNextUntranslatedRequested, this, &EditorTab::gotoNextUntranslated);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoNextUntranslatedRequested, this, &EditorTab::gotoNextUntranslated);
     connect(this, &EditorTab::signalNextUntranslatedAvailable, action, &QAction::setEnabled);
 
-    ADD_ACTION_SHORTCUT_ICON("go_prev_fuzzyUntr", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Previous not ready"), Qt::CTRL + Qt::SHIFT/*ALT*/ + Qt::Key_PageUp, "prevfuzzyuntrans")
+    ADD_ACTION_SHORTCUT_ICON("go_prev_fuzzyUntr", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Previous not ready"), Qt::ControlModifier | Qt::ShiftModifier/*ALT*/ | Qt::Key_PageUp, "prevfuzzyuntrans")
     connect(action, &QAction::triggered, this, &EditorTab::gotoPrevFuzzyUntr);
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevFuzzyUntrRequested, this, &EditorTab::gotoPrevFuzzyUntr);
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevFuzzyUntrRequested, this, &EditorTab::gotoPrevFuzzyUntr);
     connect(this, &EditorTab::signalPriorFuzzyOrUntrAvailable, action, &QAction::setEnabled);
 
-    ADD_ACTION_SHORTCUT_ICON("go_next_fuzzyUntr", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Next not ready"), Qt::CTRL + Qt::SHIFT + Qt::Key_PageDown, "nextfuzzyuntrans")
+    ADD_ACTION_SHORTCUT_ICON("go_next_fuzzyUntr", i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Next not ready"), Qt::ControlModifier | Qt::ShiftModifier | Qt::Key_PageDown, "nextfuzzyuntrans")
     connect(action, &QAction::triggered, this, qOverload<>(&EditorTab::gotoNextFuzzyUntr));
-    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::gotoNextFuzzyUntrRequested, this, qOverload<>(&EditorTab::gotoNextFuzzyUntr));
+    connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoNextFuzzyUntrRequested, this, qOverload<>(&EditorTab::gotoNextFuzzyUntr));
     connect(this, &EditorTab::signalNextFuzzyOrUntrAvailable, action, &QAction::setEnabled);
 
     action = nav->addAction(QStringLiteral("go_focus_earch_line"), m_transUnitsView, SLOT(setFocus()));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_L));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_L));
     action->setText(i18nc("@action:inmenu", "Focus the search line of Translation Units view"));
 
 
@@ -617,11 +580,11 @@ void EditorTab::setupActions()
 
     actionCategory = tm;
     // xgettext: no-c-format
-    ADD_ACTION_SHORTCUT("tools_tm_batch", i18nc("@action:inmenu", "Fill in all exact suggestions"), Qt::CTRL + Qt::ALT + Qt::Key_B)
+    ADD_ACTION_SHORTCUT("tools_tm_batch", i18nc("@action:inmenu", "Fill in all exact suggestions"), Qt::ControlModifier | Qt::AltModifier | Qt::Key_B)
     connect(action, &QAction::triggered, _tmView, &TM::TMView::slotBatchTranslate);
 
     // xgettext: no-c-format
-    ADD_ACTION_SHORTCUT("tools_tm_batch_fuzzy", i18nc("@action:inmenu", "Fill in all exact suggestions and mark as fuzzy"), Qt::CTRL + Qt::ALT + Qt::Key_N)
+    ADD_ACTION_SHORTCUT("tools_tm_batch_fuzzy", i18nc("@action:inmenu", "Fill in all exact suggestions and mark as fuzzy"), Qt::ControlModifier | Qt::AltModifier | Qt::Key_N)
     connect(action, &QAction::triggered, _tmView, &TM::TMView::slotBatchTranslateFuzzy);
 
 //MergeMode
@@ -637,7 +600,7 @@ void EditorTab::setupActions()
     action->setStatusTip(i18nc("@info:status", "Previous entry which is translated differently in the file being merged, including empty translations in merge source"));
     action->setToolTip(action->statusTip());
     action->setWhatsThis(action->statusTip());
-    ac->setDefaultShortcut(action, QKeySequence(Qt::ALT + Qt::Key_Up));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::AltModifier | Qt::Key_Up));
 
     connect(m_syncView, &MergeView::signalPriorChangedAvailable, action, &QAction::setEnabled);
     m_syncView->addAction(action);
@@ -647,20 +610,20 @@ void EditorTab::setupActions()
     action->setStatusTip(i18nc("@info:status", "Next entry which is translated differently in the file being merged, including empty translations in merge source"));
     action->setToolTip(action->statusTip());
     action->setWhatsThis(action->statusTip());
-    ac->setDefaultShortcut(action, QKeySequence(Qt::ALT + Qt::Key_Down));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::AltModifier | Qt::Key_Down));
     connect(m_syncView, &MergeView::signalNextChangedAvailable, action, &QAction::setEnabled);
     m_syncView->addAction(action);
 
     action = sync1->addAction(QStringLiteral("merge_nextapproved"), m_syncView, SLOT(gotoNextChangedApproved()));
     action->setText(i18nc("@action:inmenu", "Next different approved"));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::ALT + Qt::META + Qt::Key_Down));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::AltModifier | Qt::MetaModifier | Qt::Key_Down));
     connect(m_syncView, &MergeView::signalNextChangedAvailable, action, &QAction::setEnabled);
     m_syncView->addAction(action);
 
     action = sync1->addAction(QStringLiteral("merge_accept"), m_syncView, SLOT(mergeAccept()));
     action->setText(i18nc("@action:inmenu", "Copy from merging source"));
     action->setEnabled(false);
-    ac->setDefaultShortcut(action, QKeySequence(Qt::ALT + Qt::Key_Return));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::AltModifier | Qt::Key_Return));
     connect(m_syncView, &MergeView::signalEntryWithMergeDisplayed, action, &QAction::setEnabled);
     m_syncView->addAction(action);
 
@@ -669,15 +632,15 @@ void EditorTab::setupActions()
     action->setStatusTip(i18nc("@info:status", "This changes only empty and non-ready entries in base file"));
     action->setToolTip(action->statusTip());
     action->setWhatsThis(action->statusTip());
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_A));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::AltModifier | Qt::Key_A));
     connect(m_syncView, &MergeView::mergeCatalogAvailable, action, &QAction::setEnabled);
     m_syncView->addAction(action);
-    //action->setShortcut(Qt::ALT+Qt::Key_E);
+    //action->setShortcut(Qt::AltModifier+Qt::Key_E);
 
     action = sync1->addAction(QStringLiteral("merge_back"), m_syncView, SLOT(mergeBack()));
     action->setText(i18nc("@action:inmenu", "Copy to merging source"));
     connect(m_syncView, &MergeView::mergeCatalogAvailable, action, &QAction::setEnabled);
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Return));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::AltModifier | Qt::Key_Return));
     m_syncView->addAction(action);
 
 
@@ -781,7 +744,6 @@ void EditorTab::updateCaptionPath()
 bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QString, QMdiSubWindow*> openedFiles, bool silent)
 {
     if (!m_catalog->isClean()) {
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         switch (KMessageBox::warningTwoActionsCancel(
                     SettingsController::instance()->mainWindowPtr(),
                     i18nc("@info", "The document contains unsaved changes.\n"
@@ -799,17 +761,6 @@ bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QStrin
             return false;
         default:;
         }
-#else
-        switch (KMessageBox::warningYesNoCancel(SettingsController::instance()->mainWindowPtr(),
-                                                i18nc("@info", "The document contains unsaved changes.\n"
-                                                        "Do you want to save your changes or discard them?"), i18nc("@title:window", "Warning"),
-                                                KStandardGuiItem::save(), KStandardGuiItem::discard())
-               ) {
-        case KMessageBox::Yes: if (!saveFile()) return false; break;
-        case KMessageBox::Cancel:               return false;
-        default:;
-        }
-#endif
     }
     if (suggestedDirPath.isEmpty())
         suggestedDirPath = m_catalog->url();
@@ -916,7 +867,7 @@ bool EditorTab::saveFileAs(const QString& defaultPath)
                        QFileInfo(defaultPath.isEmpty() ? m_catalog->url() : defaultPath).absoluteFilePath(), m_catalog->fileType());
     if (filePath.isEmpty()) return false;
     if (!Catalog::extIsSupported(filePath) && m_catalog->url().contains(QLatin1Char('.')))
-        filePath += m_catalog->url().midRef(m_catalog->url().lastIndexOf(QLatin1Char('.')));
+        filePath += QStringView(m_catalog->url()).mid(m_catalog->url().lastIndexOf(QLatin1Char('.')));
 
     return saveFile(filePath);
 }
@@ -969,7 +920,6 @@ bool EditorTab::queryClose()
     if (clean)
         return true;
 
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     switch (KMessageBox::warningTwoActionsCancel(
                 this,
                 i18nc("@info", "The document contains unsaved changes.\n"
@@ -984,16 +934,6 @@ bool EditorTab::queryClose()
     default:
         return false;
     }
-#else
-    switch (KMessageBox::warningYesNoCancel(this,
-                                            i18nc("@info", "The document contains unsaved changes.\n"
-                                                    "Do you want to save your changes or discard them?"), i18nc("@title:window", "Warning"),
-                                            KStandardGuiItem::save(), KStandardGuiItem::discard())) {
-    case KMessageBox::Yes: return saveFile();
-    case KMessageBox::No:  return true;
-    default:               return false;
-    }
-#endif
 }
 
 
@@ -1273,35 +1213,35 @@ void EditorTab::toggleApprovementGotoNextFuzzyUntr()
 
 void EditorTab::setApproveActionTitle()
 {
-    const char* const titles[] = {
-        I18N_NOOP2("@option:check trans-unit state", "Translated"),
-        I18N_NOOP2("@option:check trans-unit state", "Signed-off"),
-        I18N_NOOP2("@option:check trans-unit state", "Approved")
+    const QStringList titles = {
+        i18nc("@option:check trans-unit state", "Translated"),
+        i18nc("@option:check trans-unit state", "Signed-off"),
+        i18nc("@option:check trans-unit state", "Approved")
     };
-    const char* const helpText[] = {
-        I18N_NOOP2("@info:tooltip", "Translation is done (although still may need a review)"),
-        I18N_NOOP2("@info:tooltip", "Translation has received positive review"),
-        I18N_NOOP2("@info:tooltip", "Entry is fully localized (i.e. final)")
+    const QStringList helpText = {
+        i18nc("@info:tooltip", "Translation is done (although still may need a review)"),
+        i18nc("@info:tooltip", "Translation has received positive review"),
+        i18nc("@info:tooltip", "Entry is fully localized (i.e. final)")
     };
 
     int role = m_catalog->activePhaseRole();
     if (role == ProjectLocal::Undefined)
         role = Project::local()->role();
-    m_approveAction->setText(i18nc("@option:check trans-unit state", titles[role]));
-    m_approveAction->setToolTip(i18nc("@info:tooltip", helpText[role]));
+    m_approveAction->setText(titles[role]);
+    m_approveAction->setToolTip(helpText[role]);
     m_approveAndGoAction->setVisible(role == ProjectLocal::Approver);
 }
 
 void EditorTab::showStatesMenu()
 {
-    m_stateAction->menu()->clear();
+    m_stateAction->popupMenu()->clear();
     if (!(m_catalog->capabilities()&ExtendedStates)) {
-        QAction* a = m_stateAction->menu()->addAction(i18nc("@info:status 'fuzzy' in gettext terminology", "Needs review"));
+        QAction* a = m_stateAction->popupMenu()->addAction(i18nc("@info:status 'fuzzy' in gettext terminology", "Needs review"));
         a->setData(QVariant(-1));
         a->setCheckable(true);
         a->setChecked(!m_catalog->isApproved(m_currentPos));
 
-        a = m_stateAction->menu()->addAction(i18nc("@info:status 'non-fuzzy' in gettext terminology", "Ready"));
+        a = m_stateAction->popupMenu()->addAction(i18nc("@info:status 'non-fuzzy' in gettext terminology", "Ready"));
         a->setData(QVariant(-2));
         a->setCheckable(true);
         a->setChecked(m_catalog->isApproved(m_currentPos));
@@ -1311,15 +1251,15 @@ void EditorTab::showStatesMenu()
 
     TargetState state = m_catalog->state(m_currentPos);
 
-    const char* const* states = Catalog::states();
+    const QStringList states = Catalog::translatedStates();
     for (int i = 0; i < StateCount; ++i) {
-        QAction* a = m_stateAction->menu()->addAction(i18n(states[i]));
+        QAction* a = m_stateAction->popupMenu()->addAction(states[i]);
         a->setData(QVariant(i));
         a->setCheckable(true);
         a->setChecked(state == i);
 
         if (i == New || i == Translated || i == Final)
-            m_stateAction->menu()->addSeparator();
+            m_stateAction->popupMenu()->addSeparator();
     }
 }
 
@@ -1330,7 +1270,7 @@ void EditorTab::setState(QAction* a)
     else
         m_view->setState(TargetState(a->data().toInt()));
 
-    m_stateAction->menu()->clear();
+    m_stateAction->popupMenu()->clear();
 }
 
 void EditorTab::openPhasesWindow()
@@ -1413,21 +1353,13 @@ void EditorTab::pologyHasFinished(int exitCode, QProcess::ExitStatus exitStatus)
 
 void EditorTab::clearTranslatedEntries()
 {
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     switch (KMessageBox::warningContinueCancel(
                 this,
                 i18nc("@info", "This will delete all the translations from the file.\n"
                       "Do you really want to clear all translated entries?"),
                 i18nc("@title:window", "Warning"),
                 KStandardGuiItem::clear())) {
-    case KMessageBox::PrimaryAction: {
-#else
-    switch (KMessageBox::warningYesNoCancel(this,
-                                            i18nc("@info", "This will delete all the translations from the file.\n"
-                                                    "Do you really want to clear all translated entries?"), i18nc("@title:window", "Warning"),
-                                            KStandardGuiItem::yes(), KStandardGuiItem::no())) {
-    case KMessageBox::Yes: {
-#endif
+    case KMessageBox::Continue: {
         DocPosition pos(0);
         do {
             removeTargetSubstring(m_catalog, pos);
@@ -1445,8 +1377,8 @@ void EditorTab::displayWordCount()
     //TODO in trans and fuzzy separately
     int sourceCount = 0;
     int targetCount = 0;
-    QRegExp rxClean(Project::instance()->markup() + QLatin1Char('|') + Project::instance()->accel()); //cleaning regexp; NOTE isEmpty()?
-    QRegExp rxSplit(QStringLiteral("\\W|\\d"));//splitting regexp
+    const QRegularExpression rxClean(Project::instance()->markup() + QLatin1Char('|') + Project::instance()->accel()); //cleaning regexp; NOTE isEmpty()?
+    const QRegularExpression rxSplit(QStringLiteral("\\W|\\d"));//splitting regexp
     DocPosition pos(0);
     do {
         QString msg = m_catalog->source(pos);
@@ -1553,7 +1485,6 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
 
     QString dir = Project::instance()->local()->sourceDir();
     if (dir.isEmpty()) {
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         switch (KMessageBox::questionTwoActionsCancel(
                     SettingsController::instance()->mainWindowPtr(),
                     i18nc("@info", "Would you like to search for the source file locally or via lxr.kde.org?"),
@@ -1569,14 +1500,6 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
         case KMessageBox::SecondaryAction:
             openLxrSearch(srcFileRelPath);
             return;
-#else
-        switch (KMessageBox::questionYesNoCancel(SettingsController::instance()->mainWindowPtr(),
-                i18nc("@info", "Would you like to search for the source file locally or via lxr.kde.org?"), i18nc("@title:window", "Source file lookup"),
-                KGuiItem(i18n("Locally")), KGuiItem(QStringLiteral("lxr.kde.org"))
-                                                )) {
-        case KMessageBox::Yes: break;
-        case KMessageBox::No: openLxrSearch(srcFileRelPath);
-#endif
         case KMessageBox::Cancel:
         default:
             return;
@@ -1592,7 +1515,7 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
                 return;
             }
             bool found = false;
-            QByteArray fn = srcFileRelPath.midRef(srcFileRelPath.lastIndexOf(QLatin1Char('/')) + 1).toUtf8();
+            QByteArray fn = QStringView(srcFileRelPath).mid(srcFileRelPath.lastIndexOf(QLatin1Char('/')) + 1).toUtf8();
             auto it = sourceFilePaths.constFind(fn);
             while (it != sourceFilePaths.constEnd() && it.key() == fn) {
                 const QString absFilePath = QString::fromUtf8(it.value() + '/' + fn);
@@ -1605,7 +1528,6 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
                 it++;
             }
             if (!found) {
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                 switch (KMessageBox::warningTwoActionsCancel(
                             SettingsController::instance()->mainWindowPtr(),
                             i18nc("@info", "Could not find source file in the folder specified.\n"
@@ -1632,26 +1554,6 @@ void EditorTab::dispatchSrcFileOpenRequest(const QString& srcFileRelPath, int li
                 default:
                     break;
                 }
-#else
-                switch (KMessageBox::warningYesNoCancel(SettingsController::instance()->mainWindowPtr(),
-                                                        i18nc("@info", "Could not find source file in the folder specified.\n"
-                                                                "Do you want to change source files folder?"), i18nc("@title:window", "Source file lookup"),
-                                                        KStandardGuiItem::yes(), KStandardGuiItem::no(), KGuiItem(i18n("lxr.kde.org")))) {
-                case KMessageBox::Cancel:
-                    Project::instance()->local()->setSourceDir(QString());
-                    Project::instance()->resetSourceFilePaths();
-                    openLxrSearch(srcFileRelPath);
-                case KMessageBox::No:
-                    return;
-                default: {
-                    QString dir = QFileDialog::getExistingDirectory(nullptr, i18n("Select project's base folder for source file lookup"), Project::instance()->local()->sourceDir());
-                    if (dir.length()) {
-                        Project::instance()->local()->setSourceDir(dir);
-                        Project::instance()->resetSourceFilePaths();
-                    }
-                }
-                }
-#endif
             }
         };
         if (Project::instance()->isSourceFilePathsReady())
@@ -1738,7 +1640,7 @@ void EditorTab::mergeIntoOpenDocument()
             return;
         }
         QProcess::startDetached(lowriter, QStringList(args.at(1)));
-        QString reloaderScript = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("scripts/odf/xliff2odf-standalone.py"));
+        QString reloaderScript = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("scripts/odf/xliff2odf-standalone.py"));
         if (reloaderScript.length()) {
             QString python = QStandardPaths::findExecutable(QStringLiteral("python"));
             QStringList unoArgs(QStringLiteral("-c")); unoArgs.append(QStringLiteral("import uno"));
