@@ -14,8 +14,10 @@
 #include <sonnet/highlighter.h>
 #include <sonnet/speller.h>
 #include <kcolorscheme.h>
+#include <KStatefulBrush>
 
 #include <QHash>
+#include <QRegularExpression>
 #include <QTextCharFormat>
 
 
@@ -50,7 +52,7 @@ private Q_SLOTS:
 //    void setFormatRetainingUnderlines(int start, int count, QTextCharFormat format);
 private:
     struct HighlightingRule {
-        QRegExp pattern;
+        QRegularExpression pattern;
         QTextCharFormat format;
     };
     QVector<HighlightingRule> highlightingRules;
