@@ -36,7 +36,6 @@
 #include <QStringBuilder>
 #include <QTextDocument>
 #include <QStringListModel>
-#include <QTextCodec>
 
 #include <KActionCategory>
 #include <KColorScheme>
@@ -110,7 +109,7 @@ void TMDBModel::setFilter(const QString& source, const QString& target,
     } else if (m_queryType == WordOrder) {
         /*escapedSource.replace('%',"\b%");escapedSource.replace('_',"\b_");
         escapedTarget.replace('%',"\b%");escapedTarget.replace('_',"\b_");*/
-        QRegExp wre(QStringLiteral("\\W"));
+        const QRegularExpression wre(QStringLiteral("\\W"));
         QStringList sourceList = escapedSource.split(wre, Qt::SkipEmptyParts);
         QStringList targetList = escapedTarget.split(wre, Qt::SkipEmptyParts);
 
@@ -166,8 +165,6 @@ void TMDBModel::slotQueryExecuted(ExecQueryJob* job)
         Q_EMIT finalResultCountFetched(m_totalResultCount);
         return;
     }
-    query().finish();
-    query().clear();
     setQuery(*(job->query));
     m_dbOperationMutex.unlock();
     Q_EMIT resultsFetched();
@@ -314,16 +311,16 @@ QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role)
     int source_row = mapToSource(index).row();
     QString string = result.toString();
 
-    const QVector<QRegExp> regExps =
+    const QVector<QRegularExpression> regExps =
         (index.column() == TMDBModel::Source) ?
             m_rules[m_matchingRulesForSourceRow[source_row]].sources
         :
             m_rules[m_matchingRulesForSourceRow[source_row]].falseFriends;
 
-    for (const QRegExp& re : regExps) {
-        int pos = re.indexIn(string);
-        if (pos != -1)
-            return string.replace(pos, re.matchedLength(), QStringLiteral("<b>") + re.cap(0) + QStringLiteral("</b>"));
+    for (const auto& re : regExps) {
+        const auto match = re.match(string);
+        if (match.hasMatch())
+            return string.replace(match.capturedStart(), match.capturedLength(), QStringLiteral("<b>") + match.capturedView(0) + QStringLiteral("</b>"));
     }
 
     //StartLen sl=m_highlightDataForSourceRow.value(source_row).at(index.column());
@@ -395,7 +392,7 @@ TMTab::TMTab(QWidget *parent)
     connect(ui_queryOptions->doFind, &QPushButton::clicked, this, &TMTab::performQuery);
     connect(ui_queryOptions->doUpdateTM, &QPushButton::clicked, this, &TMTab::updateTM);
 
-    QShortcut* sh = new QShortcut(Qt::ControlModifier + Qt::Key_L, this);
+    QShortcut* sh = new QShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_L), this);
     connect(sh, &QShortcut::activated, ui_queryOptions->querySource, qOverload<>(&QLineEdit::setFocus));
     setFocusProxy(ui_queryOptions->querySource);
 
@@ -403,13 +400,13 @@ TMTab::TMTab(QWidget *parent)
     view->setContextMenuPolicy(Qt::ActionsContextMenu);
 
     QAction* a = new QAction(i18n("Copy source to clipboard"), view);
-    a->setShortcut(Qt::ControlModifier + Qt::Key_S);
+    a->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_S));
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     connect(a, &QAction::triggered, this, &TMTab::copySource);
     view->addAction(a);
 
     a = new QAction(i18n("Copy target to clipboard"), view);
-    a->setShortcut(QKeySequence(Qt::ControlModifier + Qt::Key_Return));
+    a->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_Return));
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     connect(a, &QAction::triggered, this, &TMTab::copyTarget);
     view->addAction(a);
@@ -423,7 +420,7 @@ TMTab::TMTab(QWidget *parent)
 
     //view->addAction(KStandardAction::copy(this),this,SLOT(),this);
     //QKeySequence::Copy?
-    //QShortcut* shortcut = new QShortcut(Qt::ControlModifier + Qt::Key_P,view,0,0,Qt::WidgetWithChildrenShortcut);
+    //QShortcut* shortcut = new QShortcut(Qt::ControlModifier | Qt::Key_P,view,0,0,Qt::WidgetWithChildrenShortcut);
     //connect(shortcut,SIGNAL(activated()), this, SLOT(copyText()));
 
     m_model = new TMDBModel(this);
@@ -505,14 +502,14 @@ TMTab::TMTab(QWidget *parent)
 
 
     KConfig config;
-    KConfigGroup cg(&config, "MainWindow");
+    KConfigGroup cg(&config, QStringLiteral("MainWindow"));
     view->header()->restoreState(QByteArray::fromBase64(cg.readEntry("TMSearchResultsHeaderState", QByteArray())));
 }
 
 TMTab::~TMTab()
 {
     KConfig config;
-    KConfigGroup cg(&config, "MainWindow");
+    KConfigGroup cg(&config, QStringLiteral("MainWindow"));
     cg.writeEntry("TMSearchResultsHeaderState", ui_queryOptions->treeView->header()->saveState().toBase64());
 
     ids.removeAll(m_dbusId);
@@ -764,8 +761,9 @@ bool TMTab::findGuiTextPackage(QString text, QString package)
     qCWarning(LOKALIZE_LOG) << package << text;
     QLineEdit* const source_target_query[] = {ui_queryOptions->queryTarget, ui_queryOptions->querySource};
     static const DocPosition::Part source_target[] = {DocPosition::Target, DocPosition::Source};
-    QTextCodec* latin1 = QTextCodec::codecForMib(4);
-    DocPosition::Part tryNowPart = source_target[latin1->canEncode(text)];
+    QStringEncoder latin1(QStringEncoder::Latin1);
+    [[maybe_unused]] const auto encoded = latin1.encode(text);
+    DocPosition::Part tryNowPart = source_target[!latin1.hasError()];
     m_partToAlsoTryLater = source_target[tryNowPart == DocPosition::Target];
 
     text.remove(Project::instance()->accel());
